@@ -150,7 +150,7 @@ def expand_modules(
         )
         if has_init or is_namespace or is_directory:
             for subfilepath in modutils.get_module_files(
-                os.path.dirname(filepath) or ".", [], list_all=is_namespace
+                os.path.dirname(filepath) or ".", ignore_list, list_all=is_namespace
             ):
                 subfilepath = os.path.normpath(subfilepath)
                 if filepath == subfilepath:
